@@ -295,6 +295,11 @@ long long ProcessesLocal::totalPhysicalMemory()
     return Total /= 1024;
 }
 
+long long ProcessesLocal::totalSwapMemory()
+{
+    return 0;
+}
+
 ProcessesLocal::~ProcessesLocal()
 {
     delete d;
